# -*- coding: utf-8 -*-
# Generated by Django 1.10.3 on 2017-01-11 16:44
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('stonefilters', '0001_initial'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='TestModel',
            new_name='TstModel',
        ),
    ]
